@@ -397,26 +397,31 @@ void MainWindow::on_quit_activated()
 
 void MainWindow::on_about_activated()
 {
+  std::vector<Glib::ustring> authors;
+  authors.push_back("Ole Laursen <olau@hardworking.dk>");
+  
+  std::vector<Glib::ustring> documenters;
+  // add documenters here
+
+  Glib::ustring description =
+    _("Fast-paced monster mashing game for GNOME. Splat the monsters "
+      "before they roll over you and take over the world of the gnomes!");
+  
   if (about.get() == 0) {
-    std::vector<Glib::ustring> authors;
-    authors.push_back("Ole Laursen <olau@hardworking.dk>");
-  
-    std::vector<Glib::ustring> documenters;
-    // add documenters here
-
+    about.reset(new Gtk::AboutDialog());
+    about->set_name(_("Monster Masher"));
+    about->set_version(VERSION);
+    // %1 is the copyright symbol
+    about->set_copyright(String::ucompose(_("Copyright %1 2003 Ole Laursen"),
+					  "\xc2\xa9"));
+    about->set_authors(authors);
+    if (!documenters.empty())
+      about->set_documenters(documenters);
+    about->set_comments(description);
     // note to translators: please fill in your names and email addresses
-    Glib::ustring translators = _("translator-credits");
-
-    Glib::ustring description =
-      _("Fast-paced monster mashing game for GNOME. Splat the monsters "
-	"before they roll over you and take over the world of the gnomes!");
-  
-    about.reset(new Gnome::UI::About(_("Monster Masher"), VERSION,
-				     _("Copyright (c) 2003 Ole Laursen"),
-				     authors, documenters, description,
-				     translators == "translator-credits"
-				     ? "" : translators, icon));
-    about->set_transient_for(*window);
+    about->set_translator_credits(_("translator-credits"));
+    about->set_logo(icon);
+    about->set_icon(icon);
     about->show();
   }
   else {
