@@ -24,9 +24,9 @@
 #include <memory>
 
 #include <libglademm/xml.h>
-#include <libgnomeuimm/about.h>
 #include <gtkmm/label.h>
 #include <gtkmm/window.h>
+#include <gtkmm/aboutdialog.h>
 
 #include <sigc++/trackable.h>
 
@@ -113,7 +113,7 @@ private:
 
   std::auto_ptr<Canvas> canvas;
   std::auto_ptr<Graphic> background;
-  std::auto_ptr<Gnome::UI::About> about;
+  std::auto_ptr<Gtk::AboutDialog> about;
   std::auto_ptr<PreferencesWindow> preferences_window;
   std::auto_ptr<NewGameWindow> new_game_window;
   std::auto_ptr<CenterMenu> center_menu;
