@@ -25,8 +25,12 @@
 
 #include <libintl.h>
 
-#include <libgnomemm/main.h>
-#include <libgnomeuimm/init.h>
+#include <libgnomecanvasmm/init.h>
+#include <gconfmm/init.h>
+#include <gtkmm/main.h>
+
+#include <libgnome/gnome-program.h>
+#include <libgnome/gnome-init.h>
 
 #include <sigc++/slot.h>
 
@@ -36,7 +40,11 @@
 
 int main(int argc, char *argv[])
 {
-  Gnome::Main main(PACKAGE, VERSION, Gnome::UI::module_info_get(), argc, argv);
+  Gtk::Main main(argc, argv);
+  Gnome::Conf::init();
+  Gnome::Canvas::init();
+  
+  gnome_program_init(PACKAGE, VERSION, LIBGNOME_MODULE, argc, argv, NULL);
 
   try {
     // i18n
